@@ -52,6 +52,16 @@ Python >=3.6 (Python 2 is not supported).
 Install with::
 
     pip install mypythontools_cicd
+    
+There are many extras requirements that can be used with square brackets like for example
+
+    pip install mypythontools_cicd[tests]
+
+You can use `dev` which install libraries used during development like for example pylint. Most subpackages
+has own extras. `'build','deploy', 'docs', 'git', 'misc', 'tests', 'venvs'` in particular.
+
+There is also `cicd` which install all libraries necessary for cicd, but without dev dependencies. Last
+extras is `all` which use dev as well as cicd.
 
 Subpackages
 -----------
@@ -62,28 +72,45 @@ Package is divided into several subpackages
 Build your application to .exe with pyinstaller. It also builds javascript frontend with npm build if configured,
 which is used mostly in PyVueEel applications.
 
+:py:mod:`mypythontools_cicd.cicd`
+----------------------------------
+Pipeline for all the other submodules, that provide configurable CI/CD.
+
 :py:mod:`mypythontools_cicd.deploy`
 -----------------------------------
-Build package and push it to PyPi,
+Build package and push it to PyPi.
+
+:py:mod:`mypythontools_cicd.docs`
+-----------------------------------
+Provide documentation with sphinx.
+
+:py:mod:`mypythontools_cicd.git`
+--------------------------------
+Works with git. You can check branch here, commit all changes or push to repository.
 
 :py:mod:`mypythontools_cicd.misc`
----------------------------------
-Miscellaneous functions that are too small to have own subpackage.
+--------------------------------
+Miscellaneous functions that are too small to have own subpackage, like for example formatting with black.
 
-:py:mod:`mypythontools_cicd.project_utils`
-------------------------------------------
-Run cicd functions like formatting, testing or deploying.
+:py:mod:`mypythontools_cicd.packages`
+-------------------------------------
+For example, you can work with requirements here. Usually used in 'setup.py'.
 
 :py:mod:`mypythontools_cicd.project_paths`
 ------------------------------------------
-Subpackage where you can get paths used in your project (path to README,  __init__.py etc.).
+Subpackage where you can get paths used in your project (path to README,  `__init__.py` etc.).
 
 :py:mod:`mypythontools_cicd.tests`
 ----------------------------------
 Runs tests in more venvs with different python versions, also with wsl linux if configured and create coverage.
 
+:py:mod:`mypythontools_cicd.venvs`
+----------------------------------
+Works with virtual environments.
+
+
 Mypythontools
-==================
+=============
 
 There is extra library in separate repository which is not about CICD, but normal python helpers.
 
@@ -91,27 +118,18 @@ https://github.com/Malachov/mypythontools
 
 This can help you with a lot of stuff around CICD like getting project paths, generating docs, testing,
 deploying to PyPi etc.
-
-**subpackages**
-
-- config
-- misc
-- paths
-- plots
-- property
-- terminal
-- type_hints
 """
 from mypythontools_cicd import build
 from mypythontools_cicd import deploy
+from mypythontools_cicd import packages
+from mypythontools_cicd import cicd
 from mypythontools_cicd import project_paths
-from mypythontools_cicd import project_utils
-from mypythontools_cicd import tests
 from mypythontools_cicd import venvs
+from mypythontools_cicd import tests
 
-__all__ = ["build", "deploy", "project_paths", "project_utils", "tests", "venvs"]
+__all__ = ["build", "deploy", "packages", "project_paths", "cicd", "tests", "venvs"]
 
-__version__ = "0.0.23"
+__version__ = "0.0.26"
 
 __author__ = "Daniel Malachov"
 __license__ = "MIT"
